%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                   %
% Interpreter for focused linear logic                    (ILLF)    %
% AP paper                                                          %
% Signature file.                                                   %
%                                                                   %
% Authors: Elaine Pimentel and Carlos Olarte (2013)                 %
%                                                                   %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sig illf.
accum_sig blists.

kind var type.

%% Top level predicate
type illf int ->  (list o) -> o -> o.

%%%%% The logical connectives for ILLF 
%% Some are commented out because they already exist in Teyjus

%% Asynchronous operatos

%type    &       o -> o -> o.
%type    pi      (A -> o) -> o.
 type    top     o.  

type ct var -> int -> o.
type  memb_and_rest_num   A -> list A -> list A -> o.
type number_list  (list o) -> (list o) -> o.
%% Synchronous operators

%type    ,       o -> o -> o.
%type   sigma   (A -> o) -> o.  
 type   bang    o -> o.
 type   one     o. 
 type   -o    o -> o -> o. 
 type   call ((list var)  -> o -> o)  -> (list var) -> o.
infixr -o 110.

%% Function type definitions

type prove_a int -> int -> (list o) -> (list o) -> (list o) -> (list o) -> o -> o.
type prove_sr int -> int -> (list o) -> (list o) -> (list o) -> o -> o.
type prove_sl int -> int -> (list o)  -> o -> (list o) -> (list o) -> o -> o.
type prove_pi int -> int -> (list o) -> (list o) -> (list o) -> (list o) -> (list o) -> o -> o.

% Polarities
type pos            o -> o.
type neg            o -> o.
type non_atomic     o -> o.
type atomic          o -> o.

%% Clauses of side conditions
type condition_init     (list o) -> (list o) -> (list o) -> o -> o.


%% Auxiliars
type filter         list A -> list A -> list A -> o. 
type is_in          A -> list A -> o.
type split list     A -> list A -> list A -> o.
type insert_nd      A -> list A -> list A -> o.
type insert         A -> list A -> list A -> o.
type memb_and_rest  A -> list A -> list A -> o.
type memb           A -> list A -> o.
type equal          list A -> list A -> o.
type body           o -> o -> o.



%% Prints
kind printcommand    type.
type pc              A -> printcommand.
type nl, fl          printcommand.
type printf          list printcommand -> o.

type print_context  (list o) -> (list o) -> o.
type print_g        (list o) -> o.
type print_o        (list o) -> o.

%% For the examples

type a o.
type a1 o.
type a2 o.
type a3 o.
type a4 o.

type b o.
type c o -> o.
type c1 o -> o.
type c2 o -> o.
type c3 o -> o.
type cc var -> o.
type dd var -> var -> o.
type d o.


